import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:loading_overlay/loading_overlay.dart';
import 'package:storebounty_auth/src/screens/otpscreen.dart';
import 'package:storebounty_auth/src/widget/alert/alertclass.dart';
import 'package:storebounty_auth/src/widget/custombutton.dart';
import 'package:storebounty_auth/src/widget/customtextfield.dart';
import 'package:storebounty_auth/src/widget/exploreappbar.dart';
import 'package:storebounty_auth/src/widget/styles/colors.dart';
import 'package:storebounty_auth/src/widget/styles/textstles.dart';
import 'package:storebounty_auth/storebounty_auth_v1.dart';
import 'package:storebounty_init/storebountyinit.dart';

class ForgotPasswordScreen extends StatefulWidget {
  static const pageId = "forgot-password-screen";
  final VoidCallback onOtpSent;
  const ForgotPasswordScreen({super.key, required this.onOtpSent});

  @override
  State<ForgotPasswordScreen> createState() => _ForgotPasswordScreenState();
}

class _ForgotPasswordScreenState extends State<ForgotPasswordScreen> {
  TextEditingController emailResetPasswordCtx = TextEditingController();
  final _formState = GlobalKey<FormState>();
  bool _isLoading = false;
  Color? defaultColor;
  List<dynamic> images = [];
  String currency = "NGN";

  @override
  void initState() {
    getColor();
    // resetDiscountCode();
    super.initState();
  }

  getColor() async {
    var colorString = await StoreBountyInit.getStoreColor() ?? "#000000";
    defaultColor = Color(int.parse("0xff" + colorString.substring(1)));
    var currencySymbol = await StoreBountyInit.getCurrencySymbol();
    currency = currencySymbol!;
    setState(() {});
  }

  resetPasswordStart()async{

    try{

      setState(() {
        _isLoading = true;
      });

      var body = {
        "email": emailResetPasswordCtx.text.trim()
      };

      final response = await StorebountyAuth.sendResetPasswordOtp(body);

     widget.onOtpSent();

    }catch(e){
      AlertClass.error(context, "$e");
      setState(() {
        _isLoading = false;
      });

    }

  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        FocusScope.of(context).unfocus();
      },
      child: LoadingOverlay(
        isLoading: _isLoading,
        color: defaultColor?.withOpacity(0.2) ?? AppColors.defaultColor,
        progressIndicator: CircularProgressIndicator(color: defaultColor ?? AppColors.black, valueColor: AlwaysStoppedAnimation<Color>(defaultColor ?? AppColors.black),),
        child: Scaffold(
          backgroundColor: AppColors.whiteColor,
          appBar: ExploreAppBar(
            title: 'Forgot Password', onClick: () {
            print("object");
            Navigator.pop(context);
          },
            showLeftIcon: false,
          ),
          body: Container(
            child: SingleChildScrollView(
              child: Column(
                children: [
                  SizedBox(
                    height: 41,
                  ),
                  Form(
                    key: _formState,
                    child: Container(
                        margin: EdgeInsets.symmetric(horizontal: 24),
                        child: CustomTextFormField(
                          labelText: 'Email',
                          hintText: 'Enter your email',
                          controller: emailResetPasswordCtx,
                          validator: (value){
                            if(value == ""){
                              return "required";
                            }
                            return null;
                          },
                        )),
                  ),
                  SizedBox(
                    height: 20,
                  ),
                  Container(
                      margin: EdgeInsets.symmetric(horizontal: 24),
                      child: Text("We’ll send you a verification code to your email", style: Styles.p3(fontSize: 13),)),
                  SizedBox(
                    height: 397,
                  ),
                  Container(
                    height: 54,
                    margin: EdgeInsets.symmetric(horizontal: 24),
                    child: Row(
                      children: [
                        Expanded(
                          child: CustomButton(
                            text: "Send",
                            color: defaultColor ?? AppColors.black,
                            onPressed: () {
                              if(!_formState.currentState!.validate()){
                                return;
                              }
                              resetPasswordStart();

                            },
                          ),
                        ),
                      ],
                    ),
                  ),
                  SizedBox(
                    height: 20,
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}
