import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:loading_overlay/loading_overlay.dart';
import 'package:otp_text_field/otp_field.dart';
import 'package:otp_text_field/style.dart';
import 'package:storebounty_auth/src/widget/alert/alertclass.dart';
import 'package:storebounty_auth/src/widget/custombutton.dart';
import 'package:storebounty_auth/src/widget/customtextfield.dart';
import 'package:storebounty_auth/src/widget/styles/colors.dart';
import 'package:storebounty_auth/src/widget/styles/textstles.dart';
import 'package:storebounty_auth/storebounty_auth_v1.dart';
import 'package:storebounty_init/storebountyinit.dart';

class OtpScreen extends StatefulWidget {
  static const pageId = "otp-screen";
  final String? email;
  const OtpScreen({super.key, this.email});

  @override
  State<OtpScreen> createState() => _OtpScreenState();
}

class _OtpScreenState extends State<OtpScreen> {

  TextEditingController otpResetPasswordCtx = TextEditingController();
  TextEditingController passwordResetCtx = TextEditingController();
  TextEditingController confirmPasswordResetCtx = TextEditingController();

  bool _isLoading = false;

  Color? defaultColor;

  @override
  void initState() {
    getColor();
    // resetDiscountCode();
    super.initState();
  }

  getColor() async {
    var colorString = await StoreBountyInit.getStoreColor() ?? "#000000";
    defaultColor = Color(int.parse("0xff" + colorString.substring(1)));
    var currencySymbol = await StoreBountyInit.getCurrencySymbol();
    setState(() {});
  }
  
  resetPassword()async{
    
    try{

      setState(() {
        _isLoading = true;
      });

      var body = {
        "email": widget.email,
        "otp": otpResetPasswordCtx.text.trim(),
        "new_password": passwordResetCtx.text.trim(),
        "repeat_password": confirmPasswordResetCtx.text.trim()
      };
      
      final response = await StorebountyAuth.resetPassword(body);
      setState(() {
        _isLoading = false;
      });
      
    }catch(e){
      AlertClass.error(context, "$e");
      setState(() {
        _isLoading = false;
      });
    }
    
  }

  resendOtp()async{

    try{

      setState(() {
        _isLoading = true;
      });

      var body = {
        "email": widget.email
      };

      final response = await StorebountyAuth.sendResetPasswordOtp(body);
      setState(() {
        _isLoading = false;
      });

    }catch(e){
      setState(() {
        _isLoading = false;
      });
    }

  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        FocusScope.of(context).unfocus();
      },
      child: LoadingOverlay(
        isLoading: _isLoading,
        child: Scaffold(
          backgroundColor: AppColors.whiteColor,

          body: Container(
            child: SingleChildScrollView(
              child: Column(
                children: [
                  SizedBox(
                    height: 168,
                  ),
                  Container(
                    child: SvgPicture.asset("assets/icons/otp_icon.svg"),
                  ),

                  Container(
                      margin: EdgeInsets.symmetric(horizontal: 24),
                      child: Text("OTP Verification", style: Styles.p0(fontSize: 24),)),
                  SizedBox(
                    height: 20,
                  ),
                  Container(
                    margin: EdgeInsets.symmetric(horizontal: 24),
                    child: RichText(
                      text: TextSpan(
                        text: 'Please enter ',
                        style: Styles.p3(),
                        children: <TextSpan>[
                          TextSpan(text: '4 digit', style: Styles.p3(fontWeight: FontWeight.bold, color: defaultColor ?? AppColors.black)),
                          TextSpan(text: ' code we sent to your email.', style: Styles.p3()),
                        ],
                      ),
                    ),
                  ),
                  SizedBox(height: 57,),
                  Container(
                    margin: EdgeInsets.symmetric(horizontal: 25),
                    child: OTPTextField(
                      length: 4,
                      width: MediaQuery.of(context).size.width,
                      fieldWidth: 50,
                      style: TextStyle(
                          fontSize: 17
                      ),
                      textFieldAlignment: MainAxisAlignment.spaceEvenly,
                      fieldStyle: FieldStyle.box,

                      onCompleted: (pin) {
                        print("Completed: " + pin);
                      },
                      onChanged: (pin){
                        otpResetPasswordCtx.text = pin.toString();
                      },
                    ),
                  ),
                  SizedBox(
                    height: 32,
                  ),
                  Container(
                      margin: EdgeInsets.symmetric(horizontal: 24),
                      child: CustomTextFormField(
                        labelText: 'Enter new password',
                        hintText: 'Enter new password',
                        controller: passwordResetCtx,
                        obscureText: true,
                      )),
                  SizedBox(
                    height: 20,
                  ),
                  Container(
                      margin: EdgeInsets.symmetric(horizontal: 24),
                      child: CustomTextFormField(
                        labelText: 'Confirm password',
                        hintText: 'Confirm password',
                        controller: confirmPasswordResetCtx,
                        obscureText: true,
                      )),
                  SizedBox(
                    height: 32,
                  ),
                  Container(
                    margin: EdgeInsets.symmetric(horizontal: 24),
                    child: RichText(
                      text: TextSpan(
                        text: 'Didn’t receive the OTP? ',
                        style: Styles.p0(),
                        children: <TextSpan>[
                          TextSpan(text: 'RESEND OTP',
                              style: Styles.p0(color: defaultColor ?? AppColors.black),
                              recognizer: TapGestureRecognizer()
                                ..onTap = () {
                                  resendOtp();
                                }
                          ),
                        ],
                      ),
                    ),
                  ),
                  SizedBox(
                    height: 32,
                  ),
                  Container(
                    height: 54,
                    margin: EdgeInsets.symmetric(horizontal: 24),
                    child: Row(
                      children: [
                        Expanded(
                          child: CustomButton(
                            text: "Confirm",
                            color: defaultColor ?? AppColors.black,
                            onPressed: () {
                              resetPassword();
                              // Navigator.pushNamedAndRemoveUntil(context, ResetPasswordScreen.pageId, (route) => false);
                            },
                          ),
                        ),
                      ],
                    ),
                  ),
                  SizedBox(
                    height: 20,
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}
